| SimScen | R Documentation |
simscen function This function takes the mean and covariance of the conditional forecast to draw from the conditional forecast distribution The shock uncertainty is included in the simulation by default, but can be turned off.
SimScen(
mu_eps,
Sigma_eps,
mu_y,
Sigma_y,
big_b,
big_M,
n_sim,
h,
varbls,
idx_sampled = 1:dim(mu_eps)[3],
shock_uncertainty = TRUE
)
mu_eps |
mean innovation |
Sigma_eps |
variance innovation |
mu_y |
mean forecast |
Sigma_y |
variance forecast |
big_b |
history forecast |
big_M |
IRF (innovation loading) |
n_sim |
number of simulations |
h |
horizon |
varbls |
variable names |
idx_sampled |
index of random sample to use instead of full draws (from scenarios) |
shock_uncertainty |
(logical; optional) whether to include uncertainty in shocks (default is TRUE) |
conditional forecast path and distribution
## Not run:
# Example usage after scenarios() function call
# Requires scenario results from scenarios() function
result <- SimScen(mu_eps = scenario_output$mu_eps,
Sigma_eps = scenario_output$Sigma_eps,
mu_y = scenario_output$mu_y,
Sigma_y = scenario_output$Sigma_y,
big_b = scenario_output$big_b,
big_M = scenario_output$big_M,
n_sim = 1000, h = 3, varbls = c("GDP", "CPI", "FFR"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.