View source: R/interface.R View source: R/RcppExports.R
| full_scenarios_core | R Documentation |
This function wraps the Rcpp-exported version of full_scenarios_core
and allows external users to call it with correct argument checks.
full_scenarios_core(
big_b,
big_M,
obs,
path,
shocks,
h,
n_var,
g_ = NULL,
Sigma_g_ = NULL
)
big_b |
Cube of B matrices |
big_M |
Cube of M matrices |
obs |
Indices of constrained observables |
path |
Flattened path for observables |
shocks |
Indices of shocks to be recovered |
h |
Forecast horizon |
n_var |
Number of variables |
g_ |
Optional vector of non-driving shocks |
Sigma_g_ |
Optional covariance matrix of non-driving shocks |
A list with elements depending on the input configuration. Typically includes:
Matrix of mean structural shocks
Covariance matrix of structural shocks
Matrix of conditional means of observables
Covariance matrix of observables
Slice of B matrices used
Slice of M matrices used
Indices of posterior draws used in the simulation
## Not run:
# This function is typically called internally by scenarios()
# Example usage with simulated data:
big_b <- array(rnorm(9*4*10), dim = c(9, 4, 10))
big_M <- array(rnorm(9*9*10), dim = c(9, 9, 10))
result <- full_scenarios_core(big_b, big_M, obs = 1:2,
path = c(1.0, 1.1), shocks = NA,
h = 2, n_var = 3)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.